@@ -7,27 +7,25 @@
 #include "createdialog.h"
 #include "fileviewhgpluginsettings.h"
 
-#include <QHBoxLayout>
-#include <QProcess>
-#include <QLabel>
 #include <KLocalizedString>
-#include <QLineEdit>
 #include <KMessageBox>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QLineEdit>
+#include <QProcess>
 
-HgCreateDialog::HgCreateDialog(const QString &directory, QWidget *parent):
-    DialogBase(QDialogButtonBox::Ok | QDialogButtonBox::Cancel ,parent),
-    m_workingDirectory(directory)
+HgCreateDialog::HgCreateDialog(const QString &directory, QWidget *parent)
+    : DialogBase(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, parent)
+    , m_workingDirectory(directory)
 {
     // dialog properties
-    this->setWindowTitle(xi18nc("@title:window",
-                "<application>Hg</application> Initialize Repository"));
+    this->setWindowTitle(xi18nc("@title:window", "<application>Hg</application> Initialize Repository"));
     okButton()->setText(xi18nc("@action:button", "Initialize Repository"));
 
-
     //////////////
     // Setup UI //
     //////////////
-    
+
     m_directory = new QLabel(QLatin1String("<b>") + m_workingDirectory + QLatin1String("</b>"));
     m_repoNameEdit = new QLineEdit;
 
@@ -51,19 +49,15 @@ void HgCreateDialog::done(int r)
         process.setWorkingDirectory(m_workingDirectory);
         process.start(QLatin1String("hg"), args);
         process.waitForFinished();
-        
+
         if (process.exitCode() == 0 && process.exitStatus() == QProcess::NormalExit) {
             QDialog::done(r);
-        }
-        else {
+        } else {
             KMessageBox::error(this, xi18nc("error message", "Error creating repository!"));
         }
-    }
-    else {
+    } else {
         QDialog::done(r);
     }
 }
 
-
-
 #include "moc_createdialog.cpp"
